/**
 * tdesign v1.12.2
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

var _baseFlatten = require('./dep-93a6e7a7.js');
var _overRest = require('./dep-40e0109f.js');

/**
 * Flattens `array` a single level deep.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {Array} array The array to flatten.
 * @returns {Array} Returns the new flattened array.
 * @example
 *
 * _.flatten([1, [2, [3, [4]], 5]]);
 * // => [1, 2, [3, [4]], 5]
 */
function flatten(array) {
  var length = array == null ? 0 : array.length;
  return length ? _baseFlatten.baseFlatten(array, 1) : [];
}

/**
 * A specialized version of `baseRest` which flattens the rest array.
 *
 * @private
 * @param {Function} func The function to apply a rest parameter to.
 * @returns {Function} Returns the new function.
 */
function flatRest(func) {
  return _overRest.setToString(_overRest.overRest(func, undefined, flatten), func + '');
}

exports.flatRest = flatRest;
//# sourceMappingURL=dep-3ae87727.js.map
