/**
 * tdesign v1.12.2
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

var _baseDifference = require('./dep-b275e705.js');
var _baseFlatten = require('./dep-93a6e7a7.js');
var isArrayLikeObject = require('./dep-d6f2b851.js');

/**
 * Creates an array of `array` values not included in the other given arrays
 * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * for equality comparisons. The order and references of result values are
 * determined by the first array.
 *
 * **Note:** Unlike `_.pullAll`, this method returns a new array.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {Array} array The array to inspect.
 * @param {...Array} [values] The values to exclude.
 * @returns {Array} Returns the new array of filtered values.
 * @see _.without, _.xor
 * @example
 *
 * _.difference([2, 1], [2, 3]);
 * // => [1]
 */
var difference = isArrayLikeObject.baseRest(function (array, values) {
  return isArrayLikeObject.isArrayLikeObject(array) ? _baseDifference.baseDifference(array, _baseFlatten.baseFlatten(values, 1, isArrayLikeObject.isArrayLikeObject, true)) : [];
});
var difference$1 = difference;

exports.difference = difference$1;
//# sourceMappingURL=dep-3e9ca68a.js.map
